@@ -1,3 +1,4 @@
+import copy
 import logging
 import os
 import pickle
@@ -36,7 +37,8 @@ def get_notification_url(username=None):
 def notification(request, username=None):
     if settings.DEBUG:
         with open('last_request.pkl', 'wb') as output:
-            pickle.dump(request, output)
+            obj = {'META': copy.copy(request.META), 'body': copy.copy(request.body)}
+            pickle.dump(obj, output)
     
     try:
         action = request.META['HTTP_SOAPACTION']
